aboutsummaryrefslogtreecommitdiff
path: root/common/lua/scummvm_file.h
diff options
context:
space:
mode:
authorCameron Cawley2019-09-06 08:38:14 +0100
committerFilippos Karapetis2019-09-06 10:38:14 +0300
commit713fe80b47ebda1c0f10d80d9d3d7551122e8fa8 (patch)
tree79c0e11c1fd4cef63464a28c014022dd5e3b7f95 /common/lua/scummvm_file.h
parent1c8a7800da74cd531ec92c1f04919660963b7609 (diff)
downloadscummvm-rg350-713fe80b47ebda1c0f10d80d9d3d7551122e8fa8.tar.gz
scummvm-rg350-713fe80b47ebda1c0f10d80d9d3d7551122e8fa8.tar.bz2
scummvm-rg350-713fe80b47ebda1c0f10d80d9d3d7551122e8fa8.zip
LUA: Remove references to Sword25 (#1833)
Diffstat (limited to 'common/lua/scummvm_file.h')
-rw-r--r--common/lua/scummvm_file.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/common/lua/scummvm_file.h b/common/lua/scummvm_file.h
index 72d2690a4d..6f240a8351 100644
--- a/common/lua/scummvm_file.h
+++ b/common/lua/scummvm_file.h
@@ -20,18 +20,18 @@
*
*/
-#ifndef SWORD25_SCUMMVM_FILE_H
-#define SWORD25_SCUMMVM_FILE_H
+#ifndef LUA_SCUMMVM_FILE_H
+#define LUA_SCUMMVM_FILE_H
#include "common/str.h"
-namespace Sword25 {
+namespace Lua {
/**
* The following class acts as a proxy interface to the I/O code, pretending that the ScummVM
* settings are a properly formatted 'config.lua' file
*/
-class Sword25FileProxy {
+class LuaFileProxy {
private:
Common::String _readData;
uint _readPos;
@@ -44,14 +44,14 @@ private:
void writeSettings();
void updateSetting(const Common::String &setting, const Common::String &value);
public:
- Sword25FileProxy(const Common::String &filename, const Common::String &mode);
- ~Sword25FileProxy();
+ LuaFileProxy(const Common::String &filename, const Common::String &mode);
+ ~LuaFileProxy();
bool eof() const { return _readPos >= _readData.size(); }
size_t read(void *ptr, size_t size, size_t count);
size_t write(const char *ptr, size_t count);
};
-} // End of namespace Sword25
+} // End of namespace Lua
#endif